import React, { useRef, useState, Fragment, useEffect } from 'react';
import SimpleReactValidator from 'simple-react-validator';
import { ID } from 'appwrite';

var styles = {"appwriteAuth":"_2StnK","authButtons":"_3ScY3","authForm":"_2P_-3","requestResponse":"_2PKNZ","requestError":"_1ihvz"};

var styles$1 = {"linkBtn":"_3Q6nv","imageBtn":"_2EbBu","activeBtn":"_2ENrJ","btnImageCover":"_3XKdj"};

function LinkButton(_ref) {
  var onClick = _ref.onClick,
    text = _ref.text;
  return /*#__PURE__*/React.createElement("button", {
    type: "button",
    onClick: onClick,
    className: styles$1.linkBtn
  }, " ", text, " ");
}

function ImageButton(_ref) {
  var image = _ref.image,
    text = _ref.text,
    onClick = _ref.onClick,
    active = _ref.active;
  return /*#__PURE__*/React.createElement("button", {
    onClick: onClick,
    className: styles$1.imageBtn + " " + (active && styles$1.activeBtn)
  }, /*#__PURE__*/React.createElement("span", {
    className: styles$1.btnImageCover
  }, /*#__PURE__*/React.createElement("img", {
    src: image,
    alt: text,
    className: "btn-img"
  })), text);
}

var email = "email~bljGDxRk.png";

var phone = "phone~CNjhPEIV.png";

var magicurl = "magicurl~bhtIoPfy.png";



var images = {
    __proto__: null,
    email: email,
    phone: phone,
    magicurl: magicurl
};

function AuthButton(_ref) {
  var authMethod = _ref.authMethod,
    setActiveForm = _ref.setActiveForm,
    active = _ref.active;
  var image = require("./" + images[authMethod]);
  var onClick = function onClick() {
    setActiveForm(authMethod);
  };
  return /*#__PURE__*/React.createElement(ImageButton, {
    active: active == authMethod,
    text: "continue with " + authMethod,
    onClick: onClick,
    image: image
  });
}

function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];
      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }
    return target;
  };
  return _extends.apply(this, arguments);
}

// A type of promise-like that resolves synchronously and supports only one observer

const _iteratorSymbol = /*#__PURE__*/ typeof Symbol !== "undefined" ? (Symbol.iterator || (Symbol.iterator = Symbol("Symbol.iterator"))) : "@@iterator";

const _asyncIteratorSymbol = /*#__PURE__*/ typeof Symbol !== "undefined" ? (Symbol.asyncIterator || (Symbol.asyncIterator = Symbol("Symbol.asyncIterator"))) : "@@asyncIterator";

// Asynchronously call a function and send errors to recovery continuation
function _catch(body, recover) {
	try {
		var result = body();
	} catch(e) {
		return recover(e);
	}
	if (result && result.then) {
		return result.then(void 0, recover);
	}
	return result;
}

var styles$2 = {"formHeading":"_2iQ45","form":"_d7wK5","formInputCover":"_2btAK","formSubmitBtn":"_24XR8","formExtraComponent":"_3f0mi","formError":"_2n-3t"};

function Form(_ref) {
  var heading = _ref.heading,
    fields = _ref.fields,
    onSubmit = _ref.onSubmit,
    submitText = _ref.submitText,
    ExtraComponent = _ref.ExtraComponent;
  var validator = useRef(new SimpleReactValidator({
    className: styles$2.formError
  }));
  var _useState = useState(),
    forceUpdate = _useState[1];
  function submit(e) {
    e.preventDefault();
    if (validator.current.allValid()) {
      onSubmit();
      validator.current.hideMessages();
      forceUpdate(1);
    } else {
      validator.current.showMessages();
      forceUpdate(2);
    }
  }
  return /*#__PURE__*/React.createElement("div", {
    className: styles$2.formCover
  }, /*#__PURE__*/React.createElement("div", {
    className: "formHeader"
  }, /*#__PURE__*/React.createElement("p", {
    className: styles$2.formHeading
  }, heading)), /*#__PURE__*/React.createElement("form", {
    onSubmit: submit,
    className: styles$2.form
  }, fields.map(function (field, index) {
    return /*#__PURE__*/React.createElement("div", {
      key: index,
      className: styles$2.formInputCover
    }, /*#__PURE__*/React.createElement("label", {
      htmlFor: field.name
    }, field.name), validator.current.message(field.name, field.value, field.validation), /*#__PURE__*/React.createElement("input", {
      type: field.type,
      name: field.name,
      id: field.name,
      placeholder: field.placeholder,
      value: field.value,
      onChange: field.onChange
    }));
  }), /*#__PURE__*/React.createElement("div", {
    className: styles$2.formExtraComponent
  }, ExtraComponent), /*#__PURE__*/React.createElement("input", {
    type: "submit",
    value: submitText,
    className: styles$2.formSubmitBtn
  })));
}

var AVAILABLE_AUTH_OPTIONS = {
  EMAIL_PASSWORD: "email",
  PHONE: "phone",
  MAGIC_URL: "magicurl",
  ANONYMOUS: "anonymous",
  OAUTH: "oauth",
  RESET_PASSWORD: "resetpassword"
};
var SIGNIN = 'sign in';
var SIGNUP = 'sign up';
var DEFAULT_THEME = '#f02e65';

function SignInWithEmailPassword(_ref) {
  var account = _ref.account,
    onSuccess = _ref.onSuccess,
    onLoading = _ref.onLoading,
    onError = _ref.onError,
    setActiveForm = _ref.setActiveForm;
  var initialState = {
    email: '',
    password: ''
  };
  var _useState = useState(initialState),
    user = _useState[0],
    setUser = _useState[1];
  var email = user.email,
    password = user.password;
  var onChange = function onChange(e) {
    var _extends2;
    setUser(_extends({}, user, (_extends2 = {}, _extends2[e.target.name] = e.target.value, _extends2)));
  };
  var onSubmit = function onSubmit() {
    try {
      var _temp = _catch(function () {
        onLoading();
        return Promise.resolve(account.createEmailSession(email, password)).then(function () {
          setUser(initialState);
          onSuccess();
        });
      }, function (error) {
        onError(error.message);
      });
      return Promise.resolve(_temp && _temp.then ? _temp.then(function () {}) : void 0);
    } catch (e) {
      return Promise.reject(e);
    }
  };
  var forgotPassword = function forgotPassword() {
    setActiveForm(AVAILABLE_AUTH_OPTIONS.RESET_PASSWORD);
  };
  return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Form, {
    heading: "Sign In",
    fields: [{
      name: 'email',
      type: 'email',
      placeholder: 'example@example.com',
      value: email,
      onChange: onChange,
      validation: 'required|email'
    }, {
      name: 'password',
      type: 'password',
      placeholder: 'atleat 8-character long',
      value: password,
      onChange: onChange,
      validation: 'required|min:8'
    }],
    onSubmit: onSubmit,
    submitText: "Sign In",
    ExtraComponent: /*#__PURE__*/React.createElement(LinkButton, {
      onClick: forgotPassword,
      text: "forgot password"
    })
  }));
}

function SignInWithEmailPassword$1(_ref) {
  var account = _ref.account,
    onLoading = _ref.onLoading,
    onSuccess = _ref.onSuccess,
    onError = _ref.onError;
  var initialState = {
    name: "",
    email: "",
    password: ""
  };
  var _useState = useState(initialState),
    user = _useState[0],
    setUser = _useState[1];
  var name = user.name,
    email = user.email,
    password = user.password;
  var onChange = function onChange(e) {
    var _extends2;
    setUser(_extends({}, user, (_extends2 = {}, _extends2[e.target.name] = e.target.value, _extends2)));
  };
  var onSubmit = function onSubmit() {
    try {
      var _temp = _catch(function () {
        onLoading();
        return Promise.resolve(account.create(ID.unique(), email, password, name)).then(function () {
          return Promise.resolve(account.createEmailSession(email, password)).then(function () {
            setUser(initialState);
            onSuccess();
          });
        });
      }, function (error) {
        onError(error.message);
      });
      return Promise.resolve(_temp && _temp.then ? _temp.then(function () {}) : void 0);
    } catch (e) {
      return Promise.reject(e);
    }
  };
  return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Form, {
    heading: "Sign Up",
    fields: [{
      name: "name",
      type: "name",
      placeholder: "Your name here",
      value: name,
      onChange: onChange,
      validation: "required|alpha_space"
    }, {
      name: "email",
      type: "email",
      placeholder: "example@example.com",
      value: email,
      onChange: onChange,
      validation: "required|email"
    }, {
      name: "password",
      type: "password",
      placeholder: "atleast 8-character long",
      value: password,
      onChange: onChange,
      validation: "required|min:8"
    }],
    onSubmit: onSubmit,
    submitText: "Sign Up"
  }));
}

function EmailPassword(_ref) {
  var account = _ref.account,
    onLoading = _ref.onLoading,
    onSuccess = _ref.onSuccess,
    onError = _ref.onError,
    setActiveForm = _ref.setActiveForm;
  var _useState = useState(SIGNIN),
    form = _useState[0],
    setForm = _useState[1];
  var onClick = function onClick() {
    form == SIGNIN ? setForm(SIGNUP) : setForm(SIGNIN);
  };
  return /*#__PURE__*/React.createElement("div", null, form == SIGNIN ? /*#__PURE__*/React.createElement(Fragment, null, /*#__PURE__*/React.createElement(SignInWithEmailPassword, {
    account: account,
    onSuccess: onSuccess,
    onError: onError,
    onLoading: onLoading,
    setActiveForm: setActiveForm
  }), /*#__PURE__*/React.createElement("p", null, "Don't have an account, ", /*#__PURE__*/React.createElement(LinkButton, {
    text: SIGNUP,
    onClick: onClick
  }), " ")) : /*#__PURE__*/React.createElement(Fragment, null, /*#__PURE__*/React.createElement(SignInWithEmailPassword$1, {
    account: account,
    onSuccess: onSuccess,
    onError: onError,
    onLoading: onLoading
  }), /*#__PURE__*/React.createElement("p", null, "Already have an account, ", /*#__PURE__*/React.createElement(LinkButton, {
    text: SIGNIN,
    onClick: onClick
  }), " ")));
}

function Anonymous(_ref) {
  var account = _ref.account,
    onLoading = _ref.onLoading,
    onSuccess = _ref.onSuccess,
    onError = _ref.onError;
  var onClick = function onClick() {
    try {
      var _temp = _catch(function () {
        onLoading();
        return Promise.resolve(account.createAnonymousSession()).then(function () {
          onSuccess();
        });
      }, function (error) {
        onError(error.message);
      });
      return Promise.resolve(_temp && _temp.then ? _temp.then(function () {}) : void 0);
    } catch (e) {
      return Promise.reject(e);
    }
  };
  return /*#__PURE__*/React.createElement(LinkButton, {
    text: "continue as a guest",
    onClick: onClick
  });
}

function SignInWithPhone(_ref) {
  var phone = _ref.phone,
    onChange = _ref.onChange,
    onSubmit = _ref.onSubmit;
  return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Form, {
    heading: "continue with phone",
    fields: [{
      name: "phone",
      type: "text",
      placeholder: "+91**********",
      value: phone,
      onChange: onChange,
      validation: "required|phone"
    }],
    onSubmit: onSubmit,
    submitText: "Continue"
  }));
}

function VerifyPhone(_ref) {
  var secret = _ref.secret,
    onChange = _ref.onChange,
    onSubmit = _ref.onSubmit,
    resend = _ref.resend;
  return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Form, {
    heading: "verify phone",
    fields: [{
      name: "secret",
      type: "text",
      placeholder: "your secret",
      value: secret,
      onChange: onChange,
      validation: "required|numeric|min:6|max:6"
    }],
    onSubmit: onSubmit,
    submitText: "Verify",
    ExtraComponent: /*#__PURE__*/React.createElement(LinkButton, {
      onClick: resend,
      text: "resend"
    })
  }));
}

function Phone(_ref) {
  var account = _ref.account,
    onSuccess = _ref.onSuccess,
    onError = _ref.onError,
    onLoading = _ref.onLoading,
    onReset = _ref.onReset;
  var initialState = {
    id: null,
    phone: "",
    secret: ""
  };
  var _useState = useState(initialState),
    user = _useState[0],
    setUser = _useState[1];
  var onChange = function onChange(e) {
    var _extends2;
    setUser(_extends({}, user, (_extends2 = {}, _extends2[e.target.name] = e.target.value, _extends2)));
  };
  var signIn = function signIn() {
    try {
      var _temp = _catch(function () {
        onLoading();
        return Promise.resolve(account.createPhoneSession(ID.unique(), user.phone)).then(function (response) {
          setUser(_extends({}, user, {
            id: response.userId
          }));
          onReset();
        });
      }, function (error) {
        onError(error.message);
      });
      return Promise.resolve(_temp && _temp.then ? _temp.then(function () {}) : void 0);
    } catch (e) {
      return Promise.reject(e);
    }
  };
  var verify = function verify() {
    try {
      var _temp2 = _catch(function () {
        onLoading();
        return Promise.resolve(account.updatePhoneSession(user.id, user.secret)).then(function () {
          onSuccess();
        });
      }, function (error) {
        onError(error.message);
      });
      return Promise.resolve(_temp2 && _temp2.then ? _temp2.then(function () {}) : void 0);
    } catch (e) {
      return Promise.reject(e);
    }
  };
  return /*#__PURE__*/React.createElement("div", null, !user.id ?
  /*#__PURE__*/
  React.createElement(SignInWithPhone, {
    phone: user.phone,
    onChange: onChange,
    onSubmit: signIn
  }) :
  /*#__PURE__*/
  React.createElement(VerifyPhone, {
    secret: user.secret,
    onChange: onChange,
    onSubmit: verify,
    resend: signIn
  }));
}

var styles$3 = {"card":"_2Ha6u","cardHeading":"_2aJg8"};

function Card(_ref) {
  var children = _ref.children,
    image = _ref.image,
    heading = _ref.heading,
    text = _ref.text;
  return /*#__PURE__*/React.createElement("div", {
    className: styles$3.card
  }, /*#__PURE__*/React.createElement("img", {
    src: image,
    alt: "card-Image"
  }), /*#__PURE__*/React.createElement("p", {
    className: styles$3.cardHeading
  }, heading), /*#__PURE__*/React.createElement("p", null, text), children);
}

var hello = "hello~VNVUtgER.png";

var email$1 = "email~BSwoqWWk.png";

var verify = "verify~eaKvITTd.png";

var image = require("./" + hello);
function WelcomeCard() {
  return /*#__PURE__*/React.createElement(Card, {
    image: image,
    heading: "Hey! Welcome",
    text: "It's good to see you here again"
  });
}

var image$1 = require("./" + email$1);
function LinkSentCard(_ref) {
  var name = _ref.name,
    resend = _ref.resend;
  return /*#__PURE__*/React.createElement(Card, {
    image: image$1,
    heading: "Link sent successfully",
    text: name + " link has been sent on you email"
  }, /*#__PURE__*/React.createElement("p", null, "if you didn't receive the mail, ", /*#__PURE__*/React.createElement(LinkButton, {
    text: "resend link",
    onClick: resend
  })));
}

var image$2 = require("./" + verify);
function VerifyMagicURL(_ref) {
  var verify = _ref.verify;
  useEffect(function () {
    verify();
  }, []);
  return /*#__PURE__*/React.createElement(Card, {
    image: image$2,
    heading: "Verifying",
    text: "Logging you in in few seconds"
  });
}

function SignInWithMagicURL(_ref) {
  var email = _ref.email,
    onChange = _ref.onChange,
    onSubmit = _ref.onSubmit;
  return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Form, {
    heading: "continue with Magic url",
    fields: [{
      name: "email",
      type: "email",
      placeholder: "example@example.com",
      value: email,
      onChange: onChange,
      validation: "required|email"
    }],
    onSubmit: onSubmit,
    submitText: "Continue"
  }));
}

function MagicUrl(_ref) {
  var account = _ref.account,
    onSuccess = _ref.onSuccess,
    onLoading = _ref.onLoading,
    onError = _ref.onError,
    onReset = _ref.onReset;
  var initialState = {
    id: null,
    email: "",
    secret: ""
  };
  var _useState = useState(initialState),
    user = _useState[0],
    setUser = _useState[1];
  useEffect(function () {
    var searchParams = new URL(document.location).searchParams;
    if (searchParams.get('verify') == AVAILABLE_AUTH_OPTIONS.MAGIC_URL) {
      setUser(_extends({}, user, {
        id: searchParams.get('userId'),
        secret: searchParams.get('secret')
      }));
    }
  }, []);
  var onChange = function onChange(e) {
    var _extends2;
    setUser(_extends({}, user, (_extends2 = {}, _extends2[e.target.name] = e.target.value, _extends2)));
  };
  var signIn = function signIn() {
    try {
      var _temp = _catch(function () {
        onLoading();
        return Promise.resolve(account.createMagicURLSession(ID.unique(), user.email, "" + document.location.origin + document.location.pathname + "?verify=" + AVAILABLE_AUTH_OPTIONS.MAGIC_URL)).then(function (response) {
          setUser(_extends({}, user, {
            id: response.$id
          }));
          onReset();
        });
      }, function (error) {
        console.log(error);
        onError(error.message);
      });
      return Promise.resolve(_temp && _temp.then ? _temp.then(function () {}) : void 0);
    } catch (e) {
      return Promise.reject(e);
    }
  };
  var verify = function verify() {
    try {
      var _temp2 = _catch(function () {
        onLoading();
        return Promise.resolve(account.updateMagicURLSession(user.id, user.secret)).then(function () {
          onSuccess();
        });
      }, function (error) {
        console.log(error);
        onError(error.message);
      });
      return Promise.resolve(_temp2 && _temp2.then ? _temp2.then(function () {}) : void 0);
    } catch (e) {
      return Promise.reject(e);
    }
  };
  return /*#__PURE__*/React.createElement("div", null, !user.id ?
  /*#__PURE__*/
  React.createElement(SignInWithMagicURL, {
    email: user.email,
    onChange: onChange,
    onSubmit: signIn
  }) : !user.secret ?
  /*#__PURE__*/
  React.createElement(LinkSentCard, {
    resend: signIn,
    name: "Sign in"
  }) :
  /*#__PURE__*/
  React.createElement(VerifyMagicURL, {
    verify: verify
  }));
}

var amazon = "amazon~bihWQeTW.png";

var apple = "apple~qhByLKfF.png";

var auth0 = "auth0~FRUVcmZP.png";

var authentik = "authentik~bnBTUToN.png";

var autodesk = "autodesk~bAXCycEb.png";

var bitbucket = "bitbucket~ZQtNSSIR.png";

var bitly = "bitly~bkaRrvrr.png";

var box = "box~TAJToCrv.png";

var dailymotion = "dailymotion~SsZAzGMO.png";

var discord = "discord~YGQBqjYB.png";

var disqus = "disqus~NbGsodAY.png";

var dropbox = "dropbox~TwdeehDF.png";

var etsy = "etsy~IeKyNRVn.png";

var facebook = "facebook~bhrkejAl.png";

var github = "github~bbzRMQfN.png";

var gitlab = "gitlab~CtmLSTXz.png";

var google = "google~dsLynVQU.png";

var linkedin = "linkedin~NDJVTeMC.png";

var microsoft = "microsoft~TnHuutVY.png";

var notion = "notion~QenByYxO.png";

var okta = "okta~YPVCjqqA.png";

var paypal = "paypal~XvfecSGg.png";

var paypalSandbox = "paypalSandbox~XvfecSGg.png";

var podio = "podio~bmRTWpZh.png";

var salesforce = "salesforce~rPaQOTJP.png";

var slack = "slack~bjDuunjR.png";

var spotify = "spotify~moLaVEJn.png";

var stripe = "stripe~EOchMnxu.png";

var tradeshift = "tradeshift~ooHHkjhi.png";

var tradeshiftBox = "tradeshiftBox~ooHHkjhi.png";

var twitch = "twitch~bnxiHisD.png";

var wordpress = "wordpress~beVKRUGR.png";

var yahoo = "yahoo~pLrsmxCd.png";

var yammer = "yammer~borYgWcN.png";

var yandex = "yandex~IfVyhCGi.png";

var zoom = "zoom~bmwMIino.png";



var images$1 = {
    __proto__: null,
    amazon: amazon,
    apple: apple,
    auth0: auth0,
    authentik: authentik,
    autodesk: autodesk,
    bitbucket: bitbucket,
    bitly: bitly,
    box: box,
    dailymotion: dailymotion,
    discord: discord,
    disqus: disqus,
    dropbox: dropbox,
    etsy: etsy,
    facebook: facebook,
    github: github,
    gitlab: gitlab,
    google: google,
    linkedin: linkedin,
    microsoft: microsoft,
    notion: notion,
    okta: okta,
    paypal: paypal,
    paypalSandbox: paypalSandbox,
    podio: podio,
    salesforce: salesforce,
    slack: slack,
    spotify: spotify,
    stripe: stripe,
    tradeshift: tradeshift,
    tradeshiftBox: tradeshiftBox,
    twitch: twitch,
    wordpress: wordpress,
    yahoo: yahoo,
    yammer: yammer,
    yandex: yandex,
    zoom: zoom
};

function OAuth(_ref) {
  var account = _ref.account,
    provider = _ref.provider,
    successUrl = _ref.successUrl;
  var image = require("./" + images$1[provider]);
  var onClick = function onClick() {
    account.createOAuth2Session(provider, successUrl);
  };
  return (
    /*#__PURE__*/
    React.createElement(ImageButton, {
      image: image,
      text: "Continue with " + provider,
      onClick: onClick
    })
  );
}

function SendResetLink(_ref) {
  var email = _ref.email,
    onChange = _ref.onChange,
    sendResetLink = _ref.sendResetLink;
  return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Form, {
    heading: "recover password",
    fields: [{
      name: "email",
      type: "email",
      placeholder: "example@example.com",
      value: email,
      onChange: onChange,
      validation: 'required|email'
    }],
    onSubmit: sendResetLink,
    submitText: "Send"
  }));
}

function UpdatePassword(_ref) {
  var password = _ref.password,
    confirmPassword = _ref.confirmPassword,
    onChange = _ref.onChange,
    updatePassword = _ref.updatePassword;
  return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Form, {
    heading: "update password",
    fields: [{
      name: 'password',
      type: 'password',
      placeholder: 'atleat 8-character long',
      value: password,
      onChange: onChange,
      validation: 'required|min:8'
    }, {
      name: 'confirmPassword',
      type: 'password',
      placeholder: 'atleast 8-character long',
      value: confirmPassword,
      onChange: onChange,
      validation: 'required|min:8'
    }],
    onSubmit: updatePassword,
    submitText: "Reset"
  }));
}

function ResetPassword(_ref) {
  var account = _ref.account,
    onReset = _ref.onReset,
    onError = _ref.onError,
    onLoading = _ref.onLoading,
    setActiveForm = _ref.setActiveForm;
  var initialState = {
    id: null,
    email: "",
    secret: "",
    password: "",
    confirmPassword: ""
  };
  var _useState = useState(initialState),
    user = _useState[0],
    setUser = _useState[1];
  useEffect(function () {
    var searchParams = new URL(document.location).searchParams;
    if (searchParams.get('verify') == AVAILABLE_AUTH_OPTIONS.RESET_PASSWORD) {
      setUser(_extends({}, user, {
        id: searchParams.get('userId'),
        secret: searchParams.get('secret')
      }));
    }
  }, []);
  var onChange = function onChange(e) {
    var _extends2;
    setUser(_extends({}, user, (_extends2 = {}, _extends2[e.target.name] = e.target.value, _extends2)));
  };
  var sendResetLink = function sendResetLink() {
    try {
      var _temp = _catch(function () {
        onLoading();
        return Promise.resolve(account.createRecovery(user.email, "" + document.location.origin + document.location.pathname + "?verify=" + AVAILABLE_AUTH_OPTIONS.RESET_PASSWORD)).then(function (response) {
          setUser(_extends({}, user, {
            id: response.$id
          }));
          onReset();
        });
      }, function (error) {
        onError(error.message);
      });
      return Promise.resolve(_temp && _temp.then ? _temp.then(function () {}) : void 0);
    } catch (e) {
      return Promise.reject(e);
    }
  };
  var updatePassword = function updatePassword() {
    try {
      var _temp2 = _catch(function () {
        return Promise.resolve(account.updateRecovery(user.id, user.secret, user.password, user.confirmPassword)).then(function () {
          onReset();
          setActiveForm(AVAILABLE_AUTH_OPTIONS.EMAIL_PASSWORD);
        });
      }, function (error) {
        onError(error.message);
      });
      return Promise.resolve(_temp2 && _temp2.then ? _temp2.then(function () {}) : void 0);
    } catch (e) {
      return Promise.reject(e);
    }
  };
  return /*#__PURE__*/React.createElement("div", null, !user.id ?
  /*#__PURE__*/
  React.createElement(SendResetLink, {
    email: user.email,
    onChange: onChange,
    sendResetLink: sendResetLink
  }) : !user.secret ?
  /*#__PURE__*/
  React.createElement(LinkSentCard, {
    resend: sendResetLink,
    name: "Password recovery"
  }) :
  /*#__PURE__*/
  React.createElement(UpdatePassword, {
    password: user.password,
    confirmPassword: user.confirmPassword,
    onChange: onChange,
    updatePassword: updatePassword
  }));
}

function AppwriteAuth(_ref) {
  var _AVAILABLE_AUTH_OPTIO;
  var appwriteAccount = _ref.appwriteAccount,
    authOptions = _ref.authOptions,
    _ref$successUrl = _ref.successUrl,
    successUrl = _ref$successUrl === void 0 ? "" + document.location.origin + document.location.pathname : _ref$successUrl,
    _ref$theme = _ref.theme,
    theme = _ref$theme === void 0 ? DEFAULT_THEME : _ref$theme;
  var _useState = useState(null),
    activeForm = _useState[0],
    setActiveForm = _useState[1];
  useEffect(function () {
    var verify = new URL(document.location).searchParams.get('verify');
    var current = verify == AVAILABLE_AUTH_OPTIONS.MAGIC_URL && AVAILABLE_AUTH_OPTIONS.MAGIC_URL || verify == AVAILABLE_AUTH_OPTIONS.RESET_PASSWORD && AVAILABLE_AUTH_OPTIONS.RESET_PASSWORD || authOptions[AVAILABLE_AUTH_OPTIONS.EMAIL_PASSWORD] && AVAILABLE_AUTH_OPTIONS.EMAIL_PASSWORD || authOptions[AVAILABLE_AUTH_OPTIONS.PHONE] && AVAILABLE_AUTH_OPTIONS.PHONE || authOptions[AVAILABLE_AUTH_OPTIONS.MAGIC_URL] && AVAILABLE_AUTH_OPTIONS.MAGIC_URL;
    setActiveForm(current);
  }, []);
  var initialRequest = {
    success: false,
    loading: false,
    error: false,
    message: ""
  };
  var _useState2 = useState(initialRequest),
    request = _useState2[0],
    setRequest = _useState2[1];
  useEffect(function () {
    if (request.success) {
      window.location = successUrl;
    }
  }, [request]);
  var onSuccess = function onSuccess() {
    setRequest({
      success: true,
      loading: false,
      error: false,
      message: ""
    });
  };
  var onLoading = function onLoading() {
    setRequest({
      success: false,
      loading: true,
      error: false,
      message: ""
    });
  };
  var onError = function onError(message) {
    setRequest({
      success: false,
      loading: false,
      error: true,
      message: message
    });
  };
  var onReset = function onReset() {
    setRequest({
      initialRequest: initialRequest
    });
  };
  return /*#__PURE__*/React.createElement("div", {
    id: "appwrite-auth",
    className: styles.appwriteAuth,
    style: {
      '--theme': theme
    }
  }, /*#__PURE__*/React.createElement("div", {
    id: "auth-form",
    className: styles.authForm
  }, (_AVAILABLE_AUTH_OPTIO = {}, _AVAILABLE_AUTH_OPTIO[AVAILABLE_AUTH_OPTIONS.EMAIL_PASSWORD] = /*#__PURE__*/React.createElement(EmailPassword, {
    account: appwriteAccount,
    onSuccess: onSuccess,
    onError: onError,
    onLoading: onLoading,
    setActiveForm: setActiveForm
  }), _AVAILABLE_AUTH_OPTIO[AVAILABLE_AUTH_OPTIONS.PHONE] = /*#__PURE__*/React.createElement(Phone, {
    account: appwriteAccount,
    onSuccess: onSuccess,
    onError: onError,
    onLoading: onLoading,
    onReset: onReset
  }), _AVAILABLE_AUTH_OPTIO[AVAILABLE_AUTH_OPTIONS.MAGIC_URL] = /*#__PURE__*/React.createElement(MagicUrl, {
    account: appwriteAccount,
    onSuccess: onSuccess,
    onError: onError,
    onLoading: onLoading,
    onReset: onReset
  }), _AVAILABLE_AUTH_OPTIO[AVAILABLE_AUTH_OPTIONS.RESET_PASSWORD] = /*#__PURE__*/React.createElement(ResetPassword, {
    account: appwriteAccount,
    onReset: onReset,
    onError: onError,
    onLoading: onLoading,
    setActiveForm: setActiveForm
  }), _AVAILABLE_AUTH_OPTIO)[activeForm] || /*#__PURE__*/React.createElement(WelcomeCard, null), request.loading && /*#__PURE__*/React.createElement("p", {
    className: styles.requestResponse
  }, "Loading"), request.error && /*#__PURE__*/React.createElement("p", {
    className: styles.requestError + " " + styles.requestResponse
  }, request.message)), /*#__PURE__*/React.createElement("div", {
    id: "auth-buttons",
    className: styles.authButtons
  }, authOptions[AVAILABLE_AUTH_OPTIONS.EMAIL_PASSWORD] && /*#__PURE__*/React.createElement(AuthButton, {
    authMethod: AVAILABLE_AUTH_OPTIONS.EMAIL_PASSWORD,
    setActiveForm: setActiveForm,
    active: activeForm
  }), authOptions[AVAILABLE_AUTH_OPTIONS.PHONE] && /*#__PURE__*/React.createElement(AuthButton, {
    authMethod: AVAILABLE_AUTH_OPTIONS.PHONE,
    setActiveForm: setActiveForm,
    active: activeForm
  }), authOptions[AVAILABLE_AUTH_OPTIONS.MAGIC_URL] && /*#__PURE__*/React.createElement(AuthButton, {
    authMethod: AVAILABLE_AUTH_OPTIONS.MAGIC_URL,
    setActiveForm: setActiveForm,
    active: activeForm
  }), authOptions[AVAILABLE_AUTH_OPTIONS.OAUTH].map(function (provider, index) {
    return /*#__PURE__*/React.createElement(OAuth, {
      key: index,
      account: appwriteAccount,
      provider: provider,
      successUrl: successUrl
    });
  }), authOptions[AVAILABLE_AUTH_OPTIONS.ANONYMOUS] && /*#__PURE__*/React.createElement(Anonymous, {
    account: appwriteAccount,
    onSuccess: onSuccess,
    onError: onError,
    onLoading: onLoading
  })));
}

export default AppwriteAuth;
//# sourceMappingURL=index.modern.js.map
